@@ -12,8 +12,9 @@
 
 """Standard curve analysis library."""
 
-from .oscillation import OscillationAnalysis, DumpedOscillationAnalysis
+from .oscillation import OscillationAnalysis, DampedOscillationAnalysis
 from .resonance import ResonanceAnalysis
 from .gaussian import GaussianAnalysis
 from .error_amplification_analysis import ErrorAmplificationAnalysis
 from .decay import DecayAnalysis
+from .bloch_trajectory import BlochTrajectoryAnalysis
