@@ -27,10 +27,12 @@ from functools import lru_cache
 from types import FunctionType, MethodType
 from typing import Any, Dict, Type, Optional, Union, Callable
 
+import lmfit
 import numpy as np
 import scipy.sparse as sps
 import uncertainties
-from qiskit.circuit import ParameterExpression, QuantumCircuit, qpy_serialization, Instruction
+from qiskit import qpy
+from qiskit.circuit import ParameterExpression, QuantumCircuit, Instruction
 from qiskit.circuit.library import BlueprintCircuit
 from qiskit.quantum_info import DensityMatrix
 from qiskit.quantum_info.operators.channel.quantum_channel import QuantumChannel
@@ -112,7 +114,7 @@ def _deprecation_warning(name: str, version: str):
     warnings.warn(
         f"Deserializated data for <{name}> stored in a deprecated serialization format."
         " Re-serialize or re-save the data to update the serialization format otherwise"
-        f" loading this data may fail in a qiskit-experiments version {version}. ",
+        f" loading this data may fail in qiskit-experiments version {version}. ",
         DeprecationWarning,
     )
 
@@ -192,7 +194,7 @@ def _decode_and_deserialize(value: Dict, deserializer: Callable, name: Optional[
         Deserialized data.
 
     Raises:
-        ValueError: if deserialization fails.
+        ValueError: If deserialization fails.
     """
     try:
         with io.BytesIO() as buff:
@@ -292,7 +294,7 @@ def _serialize_object(obj: Any, settings: Optional[Dict] = None, safe_float: boo
     Args:
         obj: The object to be serialized.
         settings: Optional, settings for reconstructing the object from kwargs.
-        safe_float: if True check float values for NaN, inf and -inf
+        safe_float: If True check float values for NaN, inf and -inf
                     and cast to strings during serialization.
 
     Returns:
@@ -361,14 +363,16 @@ def _deserialize_object_legacy(value: Dict) -> Any:
     try:
         class_name = value["__name__"]
         mod_name = value["__module__"]
-        args = value.get("__args__", tuple())
-        kwargs = value.get("__kwargs__", dict())
+        args = value.get("__args__", ())
+        kwargs = value.get("__kwargs__", {})
         mod = importlib.import_module(mod_name)
         for name, cls in inspect.getmembers(mod, inspect.isclass):
             if name == class_name:
                 return cls(*args, **kwargs)
 
-        raise Exception(f"Unable to find class {class_name} in module {mod_name}")
+        raise Exception(  # pylint: disable=broad-exception-raised
+            f"Unable to find class {class_name} in module {mod_name}"
+        )
 
     except Exception as ex:  # pylint: disable=broad-except
         traceback_msg = "".join(traceback.format_exception(type(ex), ex, ex.__traceback__))
@@ -439,7 +443,7 @@ class ExperimentEncoder(json.JSONEncoder):
         :class:`ExperimentDecoder` is invoked.
     """
 
-    def default(self, obj: Any) -> Any:  # pylint: disable=arguments-differ
+    def default(self, obj: Any) -> Any:  # pylint: disable=arguments-renamed
         if istype(obj):
             return _serialize_type(obj)
         if hasattr(obj, "__json_encode__"):
@@ -459,7 +463,11 @@ class ExperimentEncoder(json.JSONEncoder):
         if isinstance(obj, np.number):
             return obj.item()
         if dataclasses.is_dataclass(obj):
-            return _serialize_object(obj, settings=dataclasses.asdict(obj))
+            # Note that dataclass.asdict recursively convert nested dataclass into dictionary.
+            # Thus inter dataclass is unintentionally decoded as dictionary.
+            # obj.__dict__ doesn't convert inter dataclass thus serialization
+            # is offloaded to usual json serialization mechanism.
+            return _serialize_object(obj, settings=obj.__dict__)
         if isinstance(obj, uncertainties.UFloat):
             # This could be UFloat (AffineScalarFunc) or Variable.
             # UFloat is a base class of Variable that contains parameter correlation.
@@ -481,12 +489,18 @@ class ExperimentEncoder(json.JSONEncoder):
                     "version": get_object_version(cls),
                 },
             }
+        if isinstance(obj, lmfit.Model):
+            # LMFIT Model object. Delegate serialization to LMFIT.
+            return {
+                "__type__": "LMFIT.Model",
+                "__value__": obj.dumps(),
+            }
         if isinstance(obj, Instruction):
             # Serialize gate by storing it in a circuit.
             circuit = QuantumCircuit(obj.num_qubits, obj.num_clbits)
             circuit.append(obj, range(obj.num_qubits), range(obj.num_clbits))
             value = _serialize_and_encode(
-                data=circuit, serializer=lambda buff, data: qpy_serialization.dump(data, buff)
+                data=circuit, serializer=lambda buff, data: qpy.dump(data, buff)
             )
             return {"__type__": "Instruction", "__value__": value}
         if isinstance(obj, QuantumCircuit):
@@ -494,13 +508,13 @@ class ExperimentEncoder(json.JSONEncoder):
             if isinstance(obj, BlueprintCircuit):
                 obj = obj.decompose()
             value = _serialize_and_encode(
-                data=obj, serializer=lambda buff, data: qpy_serialization.dump(data, buff)
+                data=obj, serializer=lambda buff, data: qpy.dump(data, buff)
             )
             return {"__type__": "QuantumCircuit", "__value__": value}
         if isinstance(obj, ParameterExpression):
             value = _serialize_and_encode(
                 data=obj,
-                serializer=qpy_serialization._write_parameter_expression,
+                serializer=qpy._write_parameter_expression,
                 compress=False,
             )
             return {"__type__": "ParameterExpression", "__value__": value}
@@ -567,16 +581,18 @@ class ExperimentDecoder(json.JSONDecoder):
                 return _deserialize_bytes(obj_val)
             if obj_type == "set":
                 return set(obj_val)
+            if obj_type == "LMFIT.Model":
+                tmp = lmfit.Model(func=None)
+                load_obj = tmp.loads(s=obj_val)
+                return load_obj
             if obj_type == "Instruction":
-                circuit = _decode_and_deserialize(
-                    obj_val, qpy_serialization.load, name="QuantumCircuit"
-                )[0]
+                circuit = _decode_and_deserialize(obj_val, qpy.load, name="QuantumCircuit")[0]
                 return circuit.data[0][0]
             if obj_type == "QuantumCircuit":
-                return _decode_and_deserialize(obj_val, qpy_serialization.load, name=obj_type)[0]
+                return _decode_and_deserialize(obj_val, qpy.load, name=obj_type)[0]
             if obj_type == "ParameterExpression":
                 return _decode_and_deserialize(
-                    obj_val, qpy_serialization._read_parameter_expression, name=obj_type
+                    obj_val, qpy._read_parameter_expression, name=obj_type
                 )
             if obj_type == "safe_float":
                 return self._NaNs.get(obj_val, obj_val)
