@@ -23,14 +23,15 @@ from qiskit_experiments.data_processing import DataProcessor, nodes
 from qiskit_experiments.framework import BaseExperiment, Options
 from qiskit_experiments.framework.restless_mixin import RestlessMixin
 from qiskit_experiments.library.characterization.analysis import FineAmplitudeAnalysis
+from qiskit_experiments.warnings import deprecate_arguments, qubit_deprecate
 
 
 class FineAmplitude(BaseExperiment, RestlessMixin):
-    r"""Error amplifying fine amplitude calibration experiment.
+    r"""An experiment to determine the optimal pulse amplitude by amplifying gate errors.
 
     # section: overview
 
-        The :class:`FineAmplitude` calibration experiment repeats N times a gate with a pulse
+        The :class:`FineAmplitude` experiment repeats N times a gate with a pulse
         to amplify the under-/over-rotations in the gate to determine the optimal amplitude.
         The circuits are therefore of the form:
 
@@ -45,7 +46,7 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
         Here, Gate is the name of the gate which will be repeated. The user can optionally add a
         square-root of X pulse before the gates are repeated. This square-root of X pulse allows
         the analysis to differentiate between over rotations and under rotations in the case of
-        pi-pulses. Importantly, the resulting data is analyzed by a fit to a cosine function in
+        :math:`\pi`-pulses. Importantly, the resulting data is analyzed by a fit to a cosine function in
         which we try to determine the over/under rotation given an intended rotation angle per
         gate which must also be specified by the user.
 
@@ -53,7 +54,7 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
         the equator of the Bloch sphere. This is why users should insert a square-root of X pulse
         before running calibrations for :math:`\pm\pi` rotations. When all data points are close to
         the equator, it is difficult for a fitter to infer the overall scale of the error. When
-        calibrating a :math:`pi` rotation, one can use ``add_xp_circuit = True`` to insert one
+        calibrating a :math:`\pi` rotation, one can use ``add_xp_circuit = True`` to insert one
         circuit that puts the qubit in the excited state to set the scale for the other circuits.
         Furthermore, when running calibrations for :math:`\pm\pi/2` rotations users are advised
         to use an odd number of repetitions, e.g. [1, 2, 3, 5, 7, ...] to ensure that the ideal
@@ -68,25 +69,24 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
         .. code-block:: python
 
             qubit = 3
-            amp_cal = FineAmplitude(qubit, SXGate())
+            amp_cal = FineAmplitude([qubit], SXGate())
             amp_cal.set_experiment_options(
                 angle_per_gate=np.pi/2,
-                add_xp_circuit=False,
-                add_sx=False
+                phase_offset=np.pi
             )
             amp_cal.run(backend)
 
         Note that there are subclasses of :class:`FineAmplitude` such as :class:`FineSXAmplitude`
-        that set the appropriate options by default.
+        that set the appropriate options for specific gates by default.
 
     # section: analysis_ref
-        :py:class:`FineAmplitudeAnalysis`
+        :class:`FineAmplitudeAnalysis`
 
     # section: reference
         .. ref_arxiv:: 1 1504.06597
 
-    # section: tutorial
-        :doc:`/tutorials/fine_calibrations`
+    # section: manual
+        :ref:`fine-amplitude-cal`
 
     """
 
@@ -96,8 +96,8 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
 
         Experiment Options:
             repetitions (List[int]): A list of the number of times that the gate is repeated.
-            gate_type (Gate): This is a gate class such as XGate, so that one can obtain a gate
-                by doing :code:`options.gate_class()`.
+            gate (Gate): This is a gate class such as XGate, so that one can obtain a gate
+                by doing :code:`options.gate()`.
             normalization (bool): If set to True the DataProcessor will normalized the
                 measured signal to the interval [0, 1]. Defaults to True.
             add_cal_circuits (bool): If set to True then two circuits to calibrate 0 and 1 points
@@ -113,9 +113,10 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
 
         return options
 
+    @deprecate_arguments({"qubits": "physical_qubits"}, "0.5")
     def __init__(
         self,
-        qubits: Sequence[int],
+        physical_qubits: Sequence[int],
         gate: Gate,
         backend: Optional[Backend] = None,
         measurement_qubits: Sequence[int] = None,
@@ -123,13 +124,14 @@ class FineAmplitude(BaseExperiment, RestlessMixin):
         """Setup a fine amplitude experiment on the given qubit.
 
         Args:
-            qubits: The qubit(s) on which to run the fine amplitude calibration experiment.
+            physical_qubits: Sequence containing qubit(s) on which to run the
+                fine amplitude calibration experiment.
             gate: The gate that will be repeated.
             backend: Optional, the backend to run the experiment on.
             measurement_qubits: The qubits in the given physical qubits that need to
                 be measured.
         """
-        super().__init__(qubits, analysis=FineAmplitudeAnalysis(), backend=backend)
+        super().__init__(physical_qubits, analysis=FineAmplitudeAnalysis(), backend=backend)
         self.set_experiment_options(gate=gate)
 
         if measurement_qubits is not None:
@@ -259,9 +261,10 @@ class FineXAmplitude(FineAmplitude):
         the appropriate values for the default options.
     """
 
-    def __init__(self, qubit: int, backend: Optional[Backend] = None):
+    @qubit_deprecate()
+    def __init__(self, physical_qubits: Sequence[int], backend: Optional[Backend] = None):
         """Initialize the experiment."""
-        super().__init__([qubit], XGate(), backend=backend)
+        super().__init__(physical_qubits, XGate(), backend=backend)
         # Set default analysis options
         self.analysis.set_options(
             fixed_parameters={
@@ -297,9 +300,10 @@ class FineSXAmplitude(FineAmplitude):
         the appropriate values for the default options.
     """
 
-    def __init__(self, qubit: int, backend: Optional[Backend] = None):
+    @qubit_deprecate()
+    def __init__(self, physical_qubits: Sequence[int], backend: Optional[Backend] = None):
         """Initialize the experiment."""
-        super().__init__([qubit], SXGate(), backend=backend)
+        super().__init__(physical_qubits, SXGate(), backend=backend)
         # Set default analysis options
         self.analysis.set_options(
             fixed_parameters={
@@ -341,10 +345,10 @@ class FineZXAmplitude(FineAmplitude):
 
     # section: example
 
-        To run this experiment the user will have to provide the instruction schedule
+        To run this experiment, the user will have to provide the instruction schedule
         map in the transpile options that contains the schedule for the experiment.
 
-        ..code-block:: python
+        .. code-block:: python
 
             qubits = (1, 2)
             inst_map = InstructionScheduleMap()
@@ -357,14 +361,17 @@ class FineZXAmplitude(FineAmplitude):
         :code:`RZXGate(np.pi / 2)` rotation.
     """
 
-    def __init__(self, qubits: Sequence[int], backend: Optional[Backend] = None):
+    @deprecate_arguments({"qubits": "physical_qubits"}, "0.5")
+    def __init__(self, physical_qubits: Sequence[int], backend: Optional[Backend] = None):
         """Initialize the experiment."""
 
         # We cannot use RZXGate since it has a parameter so we redefine the gate.
         # Failing to do so causes issues with QuantumCircuit.calibrations.
         gate = Gate("szx", 2, [])
 
-        super().__init__(qubits, gate, backend=backend, measurement_qubits=[qubits[1]])
+        super().__init__(
+            physical_qubits, gate, backend=backend, measurement_qubits=[physical_qubits[1]]
+        )
         # Set default analysis options
         self.analysis.set_options(
             fixed_parameters={
@@ -406,19 +413,35 @@ class FineZXAmplitude(FineAmplitude):
         return options
 
     def enable_restless(
-        self, rep_delay: Optional[float] = None, override_processor_by_restless: bool = True
+        self,
+        rep_delay: Optional[float] = None,
+        override_processor_by_restless: bool = True,
+        suppress_t1_error: bool = False,
     ):
         """Enable restless measurements.
 
-        We wrap the method of the :class:`RestlessMixin` to readout both qubits. This forces
+        We wrap the method of the :class:`.RestlessMixin` to readout both qubits. This forces
         the control qubit to be in either the 0 or 1 state before the next circuit starts
         since restless measurements do not reset qubits.
+
+        Args:
+            rep_delay: The repetition delay. This is the delay between a measurement
+                and the subsequent quantum circuit. Since the backends have
+                dynamic repetition rates, the repetition delay can be set to a small
+                value which is required for restless experiments. Typical values are
+                1 us or less.
+            override_processor_by_restless: If False, a data processor that is specified in the
+                analysis options of the experiment is not overridden by the restless data
+                processor. The default is True.
+            suppress_t1_error: If True, the default is False, then no error will be raised when
+                ``rep_delay`` is larger than the T1 times of the qubits. Instead, a warning will
+                be logged as restless measurements may have a large amount of noise.
         """
         self.analysis.set_options(outcome="11")
-        super().enable_restless(rep_delay, override_processor_by_restless)
+        super().enable_restless(rep_delay, override_processor_by_restless, suppress_t1_error)
         self._measurement_qubits = range(self.num_qubits)
 
-    def _get_restless_processor(self) -> DataProcessor:
+    def _get_restless_processor(self, meas_level: int = 2) -> DataProcessor:
         """Marginalize the counts after the restless shot reordering."""
         return DataProcessor(
             "memory",
