@@ -12,8 +12,8 @@
 
 """Tomography fitter functions"""
 
+from .fitter_data import tomography_fitter_data
+from .postprocess_fit import postprocess_fitter
 from .lininv import linear_inversion
-from .scipy_lstsq import scipy_linear_lstsq
-from .scipy_lstsq import scipy_gaussian_lstsq
-from .cvxpy_lstsq import cvxpy_linear_lstsq
-from .cvxpy_lstsq import cvxpy_gaussian_lstsq
+from .scipy_lstsq import scipy_linear_lstsq, scipy_gaussian_lstsq
+from .cvxpy_lstsq import cvxpy_linear_lstsq, cvxpy_gaussian_lstsq
