@@ -20,11 +20,10 @@ import uuid
 
 from qiskit_experiments.test.fake_backend import FakeBackend
 
-from qiskit_experiments.database_service import DatabaseServiceV1
 from qiskit_experiments.database_service.device_component import DeviceComponent
 from qiskit_experiments.database_service.exceptions import (
-    DbExperimentEntryExists,
-    DbExperimentEntryNotFound,
+    ExperimentEntryExists,
+    ExperimentEntryNotFound,
 )
 
 
@@ -63,7 +62,7 @@ def requires_pandas(func: Callable) -> Callable:
     return decorated_func
 
 
-class FakeService(DatabaseServiceV1):
+class FakeService:
     """
     This extremely simple database is designated for testing and as a playground for developers.
     It does not support multi-threading.
@@ -120,17 +119,20 @@ class FakeService(DatabaseServiceV1):
         json_encoder: Type[json.JSONEncoder] = json.JSONEncoder,
         **kwargs: Any,
     ) -> str:
+        """Creates a new experiment"""
+        # currently not using json_encoder; this should be changed
+        # pylint: disable = unused-argument
         if experiment_id is None:
             experiment_id = uuid.uuid4()
 
         if experiment_id in self.exps.experiment_id.values:
-            raise DbExperimentEntryExists("Cannot add experiment with existing id")
+            raise ExperimentEntryExists("Cannot add experiment with existing id")
 
         # Clarifications about some of the columns:
         # share_level - not a parameter of `DatabaseService.create_experiment` but a parameter of
         #    `IBMExperimentService.create_experiment`. It must be supported because it is used
         #    in `DbExperimentData`.
-        # device_components - the user speicifies the device components when adding a result
+        # device_components - the user specifies the device components when adding a result
         #    (this is not a local decision of the fake service but the interface of DatabaseService
         #    and IBMExperimentService). The components of the different results of the same
         #    experiment are aggregated here in the device_components column.
@@ -143,7 +145,7 @@ class FakeService(DatabaseServiceV1):
         # figure_names - the fake service currently does not support figures. The column
         #    (degenerated to []) is required to prevent a flaw in the work with DbExperimentData.
         # backend - the query methods `experiment` and `experiments` are supposed to return an
-        #    an instansiated backend object, and not only the backend name. We assume that the fake
+        #    an instantiated backend object, and not only the backend name. We assume that the fake
         #    service works with the fake backend (class FakeBackend).
         self.exps = pd.concat(
             [
@@ -164,7 +166,7 @@ class FakeService(DatabaseServiceV1):
                             "start_datetime": datetime(2022, 1, 1)
                             + timedelta(hours=len(self.exps)),
                             "figure_names": [],
-                            "backend": FakeBackend(backend_name),
+                            "backend": FakeBackend(backend_name=backend_name),
                         }
                     ],
                     columns=self.exps.columns,
@@ -184,8 +186,9 @@ class FakeService(DatabaseServiceV1):
         tags: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> None:
+        """Updates an existing experiment"""
         if experiment_id not in self.exps.experiment_id.values:
-            raise DbExperimentEntryNotFound("Attempt to update a non-existing experiment")
+            raise ExperimentEntryNotFound("Attempt to update a non-existing experiment")
 
         row = self.exps.experiment_id == experiment_id
         if metadata is not None:
@@ -204,8 +207,10 @@ class FakeService(DatabaseServiceV1):
     def experiment(
         self, experiment_id: str, json_decoder: Type[json.JSONDecoder] = json.JSONDecoder
     ) -> Dict:
+        """Returns an experiment by experiment_id"""
+        # pylint: disable = unused-argument
         if experiment_id not in self.exps.experiment_id.values:
-            raise DbExperimentEntryNotFound("Experiment does not exist")
+            raise ExperimentEntryNotFound("Experiment does not exist")
 
         return self.exps.loc[self.exps.experiment_id == experiment_id].to_dict("records")[0]
 
@@ -221,6 +226,8 @@ class FakeService(DatabaseServiceV1):
         tags_operator: Optional[str] = "OR",
         **filters: Any,
     ) -> List[Dict]:
+        """Returns a list of experiments filtered by given criteria"""
+        # pylint: disable = unused-argument
         df = self.exps
 
         if experiment_type is not None:
@@ -287,6 +294,7 @@ class FakeService(DatabaseServiceV1):
         return df.to_dict("records")
 
     def delete_experiment(self, experiment_id: str) -> None:
+        """Deletes an experiment"""
         if experiment_id not in self.exps.experiment_id.values:
             return
 
@@ -306,11 +314,13 @@ class FakeService(DatabaseServiceV1):
         json_encoder: Type[json.JSONEncoder] = json.JSONEncoder,
         **kwargs: Any,
     ) -> str:
+        """Creates an analysis result"""
+        # pylint: disable = unused-argument
         if result_id is None:
             result_id = uuid.uuid4()
 
         if result_id in self.results.result_id.values:
-            raise DbExperimentEntryExists("Cannot add analysis result with existing id")
+            raise ExperimentEntryExists("Cannot add analysis result with existing id")
 
         # Clarifications about some of the columns:
         # backend_name - taken from the experiment.
@@ -371,8 +381,9 @@ class FakeService(DatabaseServiceV1):
         verified: bool = None,
         **kwargs: Any,
     ) -> None:
+        """Updates an analysis result"""
         if result_id not in self.results.result_id.values:
-            raise DbExperimentEntryNotFound("Attempt to update a non-existing analysis result")
+            raise ExperimentEntryNotFound("Attempt to update a non-existing analysis result")
 
         row = self.results.result_id == result_id
         if result_data is not None:
@@ -389,8 +400,10 @@ class FakeService(DatabaseServiceV1):
     def analysis_result(
         self, result_id: str, json_decoder: Type[json.JSONDecoder] = json.JSONDecoder
     ) -> Dict:
+        """Gets an analysis result by result_id"""
+        # pylint: disable = unused-argument
         if result_id not in self.results.result_id.values:
-            raise DbExperimentEntryNotFound("Analysis result does not exist")
+            raise ExperimentEntryNotFound("Analysis result does not exist")
 
         # The `experiment` method implements special handling of the backend, we skip it here.
         # It's a bit strange, so, if not required by `DbExperimentData` then we'd better skip.
@@ -410,10 +423,12 @@ class FakeService(DatabaseServiceV1):
         tags_operator: Optional[str] = "OR",
         **filters: Any,
     ) -> List[Dict]:
+        """Returns a list of analysis results filtered by the given criteria"""
+        # pylint: disable = unused-argument
         df = self.results
 
-        # TODO: skipping device components for now until we conslidate more with the provider service
-        # (in the qiskit-experiments service there is no opertor for device components,
+        # TODO: skipping device components for now until we consolidate more with the provider service
+        # (in the qiskit-experiments service there is no operator for device components,
         # so the specification for filtering is not clearly defined)
 
         if experiment_id is not None:
@@ -467,6 +482,7 @@ class FakeService(DatabaseServiceV1):
         return df.to_dict("records")
 
     def delete_analysis_result(self, result_id: str) -> None:
+        """Deletes an analysis result"""
         if result_id not in self.results.result_id.values:
             return
 
@@ -476,16 +492,19 @@ class FakeService(DatabaseServiceV1):
     def create_figure(
         self, experiment_id: str, figure: Union[str, bytes], figure_name: Optional[str]
     ) -> Tuple[str, int]:
+        """Creates a figure"""
         pass
 
     def update_figure(
         self, experiment_id: str, figure: Union[str, bytes], figure_name: str
     ) -> Tuple[str, int]:
+        """Updates a figure"""
         pass
 
     def figure(
         self, experiment_id: str, figure_name: str, file_name: Optional[str] = None
     ) -> Union[int, bytes]:
+        """Returns a figure by experiment id and figure name"""
         pass
 
     def delete_figure(
@@ -493,8 +512,10 @@ class FakeService(DatabaseServiceV1):
         experiment_id: str,
         figure_name: str,
     ) -> None:
+        """Deletes a figure"""
         pass
 
     @property
     def preferences(self) -> Dict:
+        """Returns the db service preferences"""
         return {"auto_save": False}
